@@ -30,7 +30,4 @@
 #define CONFIG_PHY_BROADCOM
 #define CONFIG_PHY_RESET_DELAY 10000 /* PHY reset delay in us*/
 
-#define CONFIG_CMD_PING
-#define CONFIG_CMD_MII
-
 #endif /* __ARCH_CONFIGS_H */
