@@ -12,8 +12,8 @@
 
 DECLARE_GLOBAL_DATA_PTR;
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_SLD3)
-static const struct uniphier_board_data ph1_sld3_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_SLD3)
+static const struct uniphier_board_data uniphier_sld3_data = {
 	.dram_freq = 1600,
 	.dram_nr_ch = 3,
 	.dram_ch[0] = {
@@ -34,8 +34,8 @@ static const struct uniphier_board_data ph1_sld3_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_LD4)
-static const struct uniphier_board_data ph1_ld4_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_LD4)
+static const struct uniphier_board_data uniphier_ld4_data = {
 	.dram_freq = 1600,
 	.dram_nr_ch = 2,
 	.dram_ddr3plus = true,
@@ -52,9 +52,9 @@ static const struct uniphier_board_data ph1_ld4_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_PRO4)
+#if defined(CONFIG_ARCH_UNIPHIER_PRO4)
 /* 1GB RAM board */
-static const struct uniphier_board_data ph1_pro4_data = {
+static const struct uniphier_board_data uniphier_pro4_data = {
 	.dram_freq = 1600,
 	.dram_nr_ch = 2,
 	.dram_ch[0] = {
@@ -70,7 +70,7 @@ static const struct uniphier_board_data ph1_pro4_data = {
 };
 
 /* 2GB RAM board */
-static const struct uniphier_board_data ph1_pro4_2g_data = {
+static const struct uniphier_board_data uniphier_pro4_2g_data = {
 	.dram_freq = 1600,
 	.dram_nr_ch = 2,
 	.dram_ch[0] = {
@@ -86,8 +86,8 @@ static const struct uniphier_board_data ph1_pro4_2g_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_SLD8)
-static const struct uniphier_board_data ph1_sld8_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_SLD8)
+static const struct uniphier_board_data uniphier_sld8_data = {
 	.dram_freq = 1333,
 	.dram_nr_ch = 2,
 	.dram_ddr3plus = true,
@@ -104,8 +104,8 @@ static const struct uniphier_board_data ph1_sld8_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_PRO5)
-static const struct uniphier_board_data ph1_pro5_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_PRO5)
+static const struct uniphier_board_data uniphier_pro5_data = {
 	.dram_freq = 1866,
 	.dram_nr_ch = 2,
 	.dram_ch[0] = {
@@ -121,8 +121,8 @@ static const struct uniphier_board_data ph1_pro5_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PROXSTREAM2)
-static const struct uniphier_board_data proxstream2_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_PXS2)
+static const struct uniphier_board_data uniphier_pxs2_data = {
 	.dram_freq = 2133,
 	.dram_nr_ch = 3,
 	.dram_ch[0] = {
@@ -143,8 +143,8 @@ static const struct uniphier_board_data proxstream2_data = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_LD6B)
-static const struct uniphier_board_data ph1_ld6b_data = {
+#if defined(CONFIG_ARCH_UNIPHIER_LD6B)
+static const struct uniphier_board_data uniphier_ld6b_data = {
 	.dram_freq = 1866,
 	.dram_nr_ch = 3,
 	.dram_ch[0] = {
@@ -165,34 +165,59 @@ static const struct uniphier_board_data ph1_ld6b_data = {
 };
 #endif
 
+#if defined(CONFIG_ARCH_UNIPHIER_LD20)
+static const struct uniphier_board_data uniphier_ld20_data = {
+	.dram_freq = 1866,
+	.dram_nr_ch = 3,
+	.dram_ch[0] = {
+		.base = 0x80000000,
+		.size = 0x40000000,
+		.width = 32,
+	},
+	.dram_ch[1] = {
+		.base = 0xc0000000,
+		.size = 0x40000000,
+		.width = 32,
+	},
+	.dram_ch[2] = {
+		.base = 0x100000000UL,
+		.size = 0x40000000,
+		.width = 32,
+	},
+};
+#endif
+
 struct uniphier_board_id {
 	const char *compatible;
 	const struct uniphier_board_data *param;
 };
 
 static const struct uniphier_board_id uniphier_boards[] = {
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_SLD3)
-	{ "socionext,ph1-sld3", &ph1_sld3_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_SLD3)
+	{ "socionext,ph1-sld3", &uniphier_sld3_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_LD4)
-	{ "socionext,ph1-ld4", &ph1_ld4_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_LD4)
+	{ "socionext,ph1-ld4", &uniphier_ld4_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_PRO4)
-	{ "socionext,ph1-pro4-ace", &ph1_pro4_2g_data, },
-	{ "socionext,ph1-pro4-sanji", &ph1_pro4_2g_data, },
-	{ "socionext,ph1-pro4", &ph1_pro4_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_PRO4)
+	{ "socionext,ph1-pro4-ace", &uniphier_pro4_2g_data, },
+	{ "socionext,ph1-pro4-sanji", &uniphier_pro4_2g_data, },
+	{ "socionext,ph1-pro4", &uniphier_pro4_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_SLD8)
-	{ "socionext,ph1-sld8", &ph1_sld8_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_SLD8)
+	{ "socionext,ph1-sld8", &uniphier_sld8_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_PRO5)
-	{ "socionext,ph1-pro5", &ph1_pro5_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_PRO5)
+	{ "socionext,ph1-pro5", &uniphier_pro5_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PROXSTREAM2)
-	{ "socionext,proxstream2", &proxstream2_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_PXS2)
+	{ "socionext,proxstream2", &uniphier_pxs2_data, },
 #endif
-#if defined(CONFIG_ARCH_UNIPHIER_PH1_LD6B)
-	{ "socionext,ph1-ld6b", &ph1_ld6b_data, },
+#if defined(CONFIG_ARCH_UNIPHIER_LD6B)
+	{ "socionext,ph1-ld6b", &uniphier_ld6b_data, },
+#endif
+#if defined(CONFIG_ARCH_UNIPHIER_LD20)
+	{ "socionext,ph1-ld20", &uniphier_ld20_data, },
 #endif
 };
 
