@@ -269,7 +269,7 @@ int board_eth_init(bd_t *bis)
 		fm_info_set_phy_address(FM1_DTSEC4,
 				CONFIG_SYS_FM1_DTSEC2_RISER_PHY_ADDR);
 		/*
-		 * XFI does not need a PHY to work, but to make U-boot
+		 * XFI does not need a PHY to work, but to make U-Boot
 		 * happy, assign a fake PHY address for a XFI port.
 		 */
 		fm_info_set_phy_address(FM1_10GEC1, 0);
@@ -408,22 +408,22 @@ void board_ft_fman_fixup_port(void *fdt, char *compat, phys_addr_t addr,
 				    sizeof(f_link));
 			break;
 		case 0x98: /* XAUI interface */
-			sprintf(alias, "phy_xaui_slot1");
+			strcpy(alias, "phy_xaui_slot1");
 			fdt_status_okay_by_alias(fdt, alias);
 
-			sprintf(alias, "phy_xaui_slot2");
+			strcpy(alias, "phy_xaui_slot2");
 			fdt_status_okay_by_alias(fdt, alias);
 			break;
 		case 0x9e: /* XAUI interface */
 		case 0x9a:
 		case 0x93:
 		case 0x91:
-			sprintf(alias, "phy_xaui_slot1");
+			strcpy(alias, "phy_xaui_slot1");
 			fdt_status_okay_by_alias(fdt, alias);
 			break;
 		case 0x97: /* XAUI interface */
 		case 0xc3:
-			sprintf(alias, "phy_xaui_slot2");
+			strcpy(alias, "phy_xaui_slot2");
 			fdt_status_okay_by_alias(fdt, alias);
 			break;
 		default:
