@@ -29,7 +29,7 @@ static int pic32_sdhci_probe(struct udevice *dev)
 		return -EINVAL;
 
 	host->ioaddr	= ioremap(addr, size);
-	host->name	= (char *)dev->name;
+	host->name	= dev->name;
 	host->quirks	= SDHCI_QUIRK_NO_HISPD_BIT | SDHCI_QUIRK_NO_CD;
 	host->bus_width	= fdtdec_get_int(gd->fdt_blob, dev->of_offset,
 					"bus-width", 4);
