@@ -127,11 +127,6 @@ static void _serial_putc(const char c, const int port)
 	NS16550_putc(PORT, c);
 }
 
-static void _serial_putc_raw(const char c, const int port)
-{
-	NS16550_putc(PORT, c);
-}
-
 static void _serial_puts(const char *s, const int port)
 {
 	while (*s) {
@@ -164,12 +159,6 @@ serial_putc_dev(unsigned int dev_index,const char c)
 	_serial_putc(c,dev_index);
 }
 
-static inline void
-serial_putc_raw_dev(unsigned int dev_index,const char c)
-{
-	_serial_putc_raw(c,dev_index);
-}
-
 static inline void
 serial_puts_dev(unsigned int dev_index,const char *s)
 {
