@@ -10,16 +10,6 @@
 
 #ifdef CONFIG_SPL_BUILD
 /* SPL needs only BOOTP + TFTP so undefine other stuff to save space */
-#undef CONFIG_CMD_CDP
-#undef CONFIG_CMD_DHCP
-#undef CONFIG_CMD_DNS
-#undef CONFIG_CMD_LINK_LOCAL
-#undef CONFIG_CMD_NFS
-#undef CONFIG_CMD_PING
-#undef CONFIG_CMD_RARP
-#undef CONFIG_CMD_SNTP
-#undef CONFIG_CMD_TFTPPUT
-#undef CONFIG_CMD_TFTPSRV
 
 #ifndef CONFIG_SPL_DM
 #undef CONFIG_DM_SERIAL
