@@ -26,13 +26,11 @@
 
 /* I2C */
 #define CONFIG_SYS_I2C_TEGRA
-#define CONFIG_CMD_I2C
 
 /* SD/MMC */
 #define CONFIG_MMC
 #define CONFIG_GENERIC_MMC
 #define CONFIG_TEGRA_MMC
-#define CONFIG_CMD_MMC
 
 /* Environment in eMMC, at the end of 2nd "boot sector" */
 #define CONFIG_ENV_IS_IN_MMC
@@ -44,15 +42,12 @@
 #define CONFIG_TEGRA_SLINK_CTRLS       6
 #define CONFIG_SF_DEFAULT_MODE         SPI_MODE_0
 #define CONFIG_SF_DEFAULT_SPEED        24000000
-#define CONFIG_CMD_SPI
-#define CONFIG_CMD_SF
 #define CONFIG_SPI_FLASH_SIZE          (4 << 20)
 
 /* USB Host support */
 #define CONFIG_USB_EHCI
 #define CONFIG_USB_EHCI_TEGRA
 #define CONFIG_USB_STORAGE
-#define CONFIG_CMD_USB
 
 /* USB networking support */
 #define CONFIG_USB_HOST_ETHER
@@ -63,11 +58,7 @@
 #define CONFIG_PCI_PNP
 #define CONFIG_CMD_PCI
 
-/* PCI networking support */
-#define CONFIG_RTL8169
-
 /* General networking support */
-#define CONFIG_CMD_DHCP
 
 #include "tegra-common-usb-gadget.h"
 #include "tegra-common-post.h"
