@@ -18,7 +18,6 @@
 #define CONFIG_MACH_TYPE		4273
 
 /* CMD */
-#define CONFIG_CMD_GREPENV
 
 /* MMC */
 #define CONFIG_SYS_FSL_USDHC_NUM	3
@@ -225,7 +224,6 @@
 #define CONFIG_STACKSIZE			(128 * 1024)
 #define CONFIG_SYS_MALLOC_LEN			(10 * 1024 * 1024)
 #define CONFIG_SYS_U_BOOT_MAX_SIZE_SECTORS	800 /* 400 KB */
-#define CONFIG_OF_BOARD_SETUP
 #define CONFIG_MISC_INIT_R
 
 /* SPL */
