@@ -61,7 +61,6 @@
 #define CONFIG_BOOTCOMMAND	"bootp;bootm"
 #endif /* CONFIG_DBAU1550 */
 
-
 /*
  * BOOTP options
  */
@@ -70,28 +69,22 @@
 #define CONFIG_BOOTP_GATEWAY
 #define CONFIG_BOOTP_HOSTNAME
 
-
 /*
  * Command line configuration.
  */
 #undef CONFIG_CMD_BEDBUG
-#undef CONFIG_CMD_FAT
-#undef CONFIG_CMD_MII
 
 #ifdef CONFIG_DBAU1550
 
-#undef CONFIG_CMD_I2C
 #undef CONFIG_CMD_IDE
 #undef CONFIG_CMD_PCMCIA
 
 #else
 
 #define CONFIG_CMD_IDE
-#define CONFIG_CMD_DHCP
 
 #endif
 
-
 /*
  * Miscellaneous configurable options
  */
@@ -147,6 +140,11 @@
 #define CONFIG_FLASH_CFI_DRIVER    1
 
 /* The following #defines are needed to get flash environment right */
+/* ROM version */
+#define CONFIG_SYS_TEXT_BASE		0xbfc00000
+/* RAM version */
+/* #define CONFIG_SYS_TEXT_BASE		0x80100000 */
+
 #define	CONFIG_SYS_MONITOR_BASE	CONFIG_SYS_TEXT_BASE
 #define	CONFIG_SYS_MONITOR_LEN		(192 << 10)
 
@@ -169,7 +167,6 @@
 
 #define CONFIG_NR_DRAM_BANKS	2
 
-
 #ifdef CONFIG_DBAU1550
 #define MEM_SIZE 192
 #else
