@@ -23,9 +23,6 @@
 #define CONFIG_SYS_FSL_ESDHC_ADDR	USDHC4_BASE_ADDR
 #define CONFIG_SYS_FSL_USDHC_NUM	2
 
-#define CONFIG_CMD_PING
-#define CONFIG_CMD_DHCP
-#define CONFIG_CMD_MII
 #define	CONFIG_FEC_MXC
 #define	CONFIG_MII
 #define IMX_FEC_BASE			ENET_BASE_ADDR
@@ -132,7 +129,6 @@
 #define CONFIG_SYS_MMC_ENV_DEV		1
 
 /* USB Configs */
-#define CONFIG_CMD_USB
 #ifdef CONFIG_CMD_USB
 #define CONFIG_USB_EHCI
 #define CONFIG_USB_EHCI_MX6
