@@ -10,6 +10,7 @@
 #define	__CONFIG_PXA_COMMON_H__
 
 #define	CONFIG_DISPLAY_CPUINFO
+#define	CONFIG_SYS_ARM_CACHE_WRITETHROUGH
 
 /*
  * KGDB
@@ -25,8 +26,6 @@
 #define	CONFIG_MMC
 #define	CONFIG_GENERIC_MMC
 #define	CONFIG_PXA_MMC_GENERIC
-#define	CONFIG_CMD_FAT
-#define	CONFIG_CMD_EXT2
 #define	CONFIG_DOS_PARTITION
 #endif
 
@@ -37,7 +36,11 @@
 #define	CONFIG_USB_OHCI_NEW
 #define	CONFIG_SYS_USB_OHCI_CPU_INIT
 #define	CONFIG_SYS_USB_OHCI_BOARD_INIT
+#ifdef CONFIG_CPU_PXA27X
+#define	CONFIG_SYS_USB_OHCI_MAX_ROOT_PORTS	3
+#else
 #define	CONFIG_SYS_USB_OHCI_MAX_ROOT_PORTS	2
+#endif
 #define	CONFIG_SYS_USB_OHCI_REGS_BASE		0x4c000000
 #define	CONFIG_SYS_USB_OHCI_SLOT_NAME		"pxa-ohci"
 #define	CONFIG_USB_STORAGE
