@@ -73,7 +73,6 @@
 #define CONFIG_USB_CLOCK	0x0001BBBB
 #define CONFIG_USB_CONFIG	0x00001000
 
-
 /*
  * BOOTP options
  */
@@ -82,24 +81,15 @@
 #define CONFIG_BOOTP_GATEWAY
 #define CONFIG_BOOTP_HOSTNAME
 
-
 /*
  * Command line configuration.
  */
-#define CONFIG_CMD_FAT
-#define CONFIG_CMD_I2C
 #define CONFIG_CMD_IDE
-#define CONFIG_CMD_PING
-#define CONFIG_CMD_DHCP
 #define CONFIG_CMD_DIAG
 #define CONFIG_CMD_IRQ
 #define CONFIG_CMD_JFFS2
-#define CONFIG_CMD_MII
 #define CONFIG_CMD_SDRAM
 #define CONFIG_CMD_DATE
-#define CONFIG_CMD_USB
-#define CONFIG_CMD_FAT
-
 
 #define CONFIG_TIMESTAMP		/* Print image info with timestamp */
 
